Changelog
=========

0.6 (2015-06-05)
----------------

- Add README.rst as symbolic link again.  Remove mauritstestpackage/README.txt.


0.5 (2015-06-05)
----------------

- Remove README.rst.

- Add changelog to long description.


0.4 (2015-06-05)
----------------

- README.rst as symbolic link.  Extra mauritstestpackage/README.txt.


0.3 (2015-06-05)
----------------

- README.txt as long description, instead of README.rst.


0.2 (2015-05-22)
----------------

- Nothing changed yet.


0.1 (2015-05-13)
----------------

- First release.
